==> react-tabbordion-0.2.2.tgz: package/demo/app.js <==
;(function() {
    var Tabbordion = React.createFactory(window.Tabbordion),
        Panel = React.createFactory(window.Panel)

    var Demo = React.createClass({
        displayName: 'Demo',
        
        getInitialState: function() {
            var INITIAL = 0

            return {
                index: INITIAL,
                demoProps: [
                    {
                        demo: 'Tabs',
                        className: 'traditional-tabs',
                        classNames: {
                            content: 'traditional-tabs-content',
                            panel: 'traditional-tabs-panel',
                            title: 'traditional-tabs-title'
                        },
                        initialIndex: INITIAL
                    },
                    {
                        animateContent: 'height',
                        demo: 'Accordion',
                        className: 'accordion',
                        classNames: {
                            animator: 'accordion-animator',
                            content: 'accordion-content',
                            panel: 'accordion-panel',
                            title: 'accordion-title'
                        },
                        initialIndex: INITIAL,
                        mode: 'toggle'
                    },
                    {
                        animateContent: 'height',
                        demo: 'Multiselect accordion',
                        className: 'accordion',
                        classNames: {
                            animator: 'accordion-animator',
                            content: 'accordion-content',
                            panel: 'accordion-panel',
                            title: 'accordion-title'
                        },
                        initialIndex: INITIAL,
                        mode: 'multiple'
                    }
                ]
            }
        },

        render: function() {
            return React.DOM.article(
                {},
                React.DOM.header(
                    {},
                    React.DOM.p({}, 'Choose display style and mode:'),
                    Tabbordion(
                        {
                            className: 'option-list',
                            classNames: {
                                panel: 'option-item option-item--horizontal',
                                title: 'option-label option-label--horizontal'
                            },
                            initialIndex: this.state.index,
                            onChange: this.setState.bind(this)
                        },
                        this.state.demoProps.map(function(props, index) {
                            return Panel({
                                key: 'demo-' + index,
                                title: React.DOM.span({}, props.demo)
                            })
                        })
                    )
                ),
                React.DOM.section(
                    {},
                    React.DOM.p({}, 'The component below remains the same, it just receives new props:'),
                    Tabbordion(
                        this.state.demoProps[this.state.index],
                        Panel(
                            { title: React.DOM.span({}, 'Panel #1') },
                            React.DOM.h2({}, 'Content Be Here'),
                            React.DOM.p({}, 'Unless we have nothing.')
                        ),
                        Panel(
                            { title: React.DOM.span({}, 'Panel #2') },
                            React.DOM.h2({}, 'More Content Be Here'),
                            React.DOM.p({}, 'But we have something.')
                        ),
                        Panel({ title: React.DOM.span({}, 'Panel #3 - No Content') }),
                        // non-Panel elements are allowed to be here
                        React.DOM.div(
                            { className: 'demo' },
                            React.DOM.small({}, 'This is just a normal div here together with the panels.'
                                + ' If you don\'t see what is awesome: doesn\'t break those nice border-radius styles!')
                        )
                    )
                )
            )
        }
    })

    React.render(React.createElement(Demo), document.getElementById('app'))
})();

==> react-tabbordion-0.2.3.tgz: package/demo/app.js <==
;(function() {
    var Tabbordion = React.createFactory(window.Tabbordion),
        Panel = React.createFactory(window.Panel)

    var Demo = React.createClass({
        displayName: 'Demo',
        
        getInitialState: function() {
            var INITIAL = 0

            return {
                index: INITIAL,
                demoProps: [
                    {
                        demo: 'Tabs',
                        className: 'traditional-tabs',
                        classNames: {
                            content: 'traditional-tabs-content',
                            panel: 'traditional-tabs-panel',
                            title: 'traditional-tabs-title'
                        },
                        initialIndex: INITIAL
                    },
                    {
                        animateContent: 'height',
                        demo: 'Accordion',
                        className: 'accordion',
                        classNames: {
                            animator: 'accordion-animator',
                            content: 'accordion-content',
                            panel: 'accordion-panel',
                            title: 'accordion-title'
                        },
                        initialIndex: INITIAL,
                        mode: 'toggle'
                    },
                    {
                        animateContent: 'height',
                        demo: 'Multiselect accordion',
                        className: 'accordion',
                        classNames: {
                            animator: 'accordion-animator',
                            content: 'accordion-content',
                            panel: 'accordion-panel',
                            title: 'accordion-title'
                        },
                        initialIndex: INITIAL,
                        mode: 'multiple'
                    }/*,
                    {
                        demo: 'Mobile tabs',
                        className: 'mobile-tabs',
                        classNames: {
                            content: 'mobile-tabs-content',
                            panel: 'mobile-tabs-panel',
                            title: 'mobile-tabs-title'
                        },
                        initialIndex: INITIAL,
                        onBeforeChange: function(newState, oldState) {
                            if (newState.index == null || oldState.index == null) {
                                this.setState({ animate: 'fade' })
                                return
                            }

                            var diffRight = Math.max(oldState.index - newState.index, 0)
                            var diffLeft = oldState.checked.length + newState.index - oldState.index

                        }.bind(this)
                    }*/
                ]
            }
        },

        render: function() {
            return React.DOM.article(
                {},
                React.DOM.header(
                    {},
                    React.DOM.p({}, 'Choose display style and mode:'),
                    Tabbordion(
                        {
                            className: 'option-list',
                            classNames: {
                                panel: 'option-item --horizontal',
                                title: 'option-label --horizontal'
                            },
                            initialIndex: this.state.index,
                            onAfterChange: this.setState.bind(this)
                        },
                        this.state.demoProps.map(function(props, index) {
                            return Panel({
                                key: 'demo-' + index,
                                title: React.DOM.span({}, props.demo)
                            })
                        })
                    )
                ),
                React.DOM.section(
                    {},
                    React.DOM.p({}, 'The component below remains the same, it just receives new props:'),
                    Tabbordion(
                        this.state.demoProps[this.state.index],
                        Panel(
                            { title: React.DOM.span({}, 'Panel #1') },
                            React.DOM.h2({}, 'Content Be Here'),
                            React.DOM.p({}, 'Unless we have nothing.')
                        ),
                        Panel(
                            { title: React.DOM.span({}, 'Panel #2') },
                            React.DOM.h2({}, 'More Content Be Here'),
                            React.DOM.p({}, 'But we have something.')
                        ),
                        Panel({ title: React.DOM.span({}, 'Panel #3 - No Content') }),
                        // non-Panel elements are allowed to be here
                        React.DOM.div(
                            { className: 'demo' },
                            React.DOM.small({}, 'This is just a normal div here together with the panels.'
                                + ' If you don\'t see what is awesome: doesn\'t break those nice border-radius styles!')
                        )
                    )
                )
            )
        }
    })

    React.render(React.createElement(Demo), document.getElementById('app'))
})();
